@@ -8,6 +8,8 @@ use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
+no if "$]" >= 5.041009, feature => 'smartmatch';
+no feature 'switch';
 with 'JSON::Schema::Modern::Vocabulary';
 
 use JSON::Schema::Modern::Utilities qw(assert_keyword_type is_type E);
